@@ -61,26 +61,16 @@ class SimpleRunner(AbstractRunner):
             print('n_past_features must be None for LSTM history features')
             return
 
-        meArg = (
-            seed, sup, layers, epochs, n_past_features, n, s, feature_type,
-            activation_type, convolution, lr_start, lr_type, low_bound, up_bound, normalize)
+        saving_key = saver.create_saving_key(seed, sup, layers, epochs, n_past_features, n, s, feature_type, activation_type, convolution, lr_start, lr_type, low_bound, up_bound, normalize)
 
-        meArgList = list(meArg)
-        meArgList = [str(it) for it in meArgList]
-        savingKey = ''.join(meArgList)
-        savingKey = savingKey.replace('[', '')
-        savingKey = savingKey.replace(']', '')
-        savingKey = savingKey.replace(',', '')
-        savingKey = savingKey.replace(' ', '')
-        savingKey = savingKey.replace('.', '')
-        # savingKey = savingKey.replace('_','')
-        savingKey = 'T_' + savingKey
 
-        print('Launching computation with parameters : '+savingKey)
+
+        print('Launching computation with parameters : '+saving_key)
 
         ## checking if the computation has already been done
-        if saver.checkRunExistence(savingKey):
-            print('Run already present : we do nothing')
+        run_found, found_table_number = saver.checkRunExistence(saving_key)
+        if run_found:
+            print('Run already present in table '+str(found_table_number)+' : we do nothing')
             return
 
         supervisors = {}
@@ -303,18 +293,18 @@ class SimpleRunner(AbstractRunner):
         # tm.y_test[tm.t:] = tm.sub_predict(tm.X[tm.t:])
         df_ret = df.fillna(method='bfill').pct_change().fillna(0).copy()
         # Process weights
-        print('processing weights for '+savingKey)
+        print('processing weights for '+saving_key)
         weight_mat, last_predicted_weights = weights.process_weights(w=tm.y_test, df=df_ret, s=s, n=n, low_bound=low_bound, up_bound=up_bound,normalize=normalize)
         # Compute portfolio perf
         portfolio = np.cumprod(np.prod(df_ret * weight_mat.values + 1, axis=1))
         if self.save_model :
-            tm.save_model_and_last_state(state=state,model_path = self.local_root_directory+savingKey)
+            tm.save_model_and_last_state(state=state,model_path = self.local_root_directory+saving_key)
         if self.dropbox_backup:
-            self.dbx.uploadFileToDropbox(filename=savingKey+'_model.torch', dropbox_subfolder = '', fullpath=self.local_root_directory+savingKey+'_model.torch')
-            self.dbx.uploadFileToDropbox(filename=savingKey+'_py.obj', dropbox_subfolder = '', fullpath=self.local_root_directory+savingKey+'_py.obj')
+            self.dbx.uploadFileToDropbox(filename=saving_key+'_model.torch', dropbox_subfolder = '', fullpath=self.local_root_directory+saving_key+'_model.torch')
+            self.dbx.uploadFileToDropbox(filename=saving_key+'_py.obj', dropbox_subfolder = '', fullpath=self.local_root_directory+saving_key+'_py.obj')
 
-        saver.saveResults(savingKey, portfolio, weight_mat, recordings_df, activations_df, last_predicted_weights)
-        print('saved '+ savingKey)
+        saver.saveResults(saving_key, portfolio, weight_mat, recordings_df, activations_df, last_predicted_weights)
+        print('saved '+ saving_key)
         return  last_predicted_weights
 
 
