@@ -102,10 +102,9 @@ class ParallelRunResultAnalyzer():
         results_df = results_df.set_index(results_df['Date'])
         results_df = results_df.drop(['Date'], axis=1)
 
-        run_empty_results = results_df.sum(axis = 0)
-        self.empty_runs_to_investigate = list(run_empty_results.index[run_empty_results == 0])
-
-        results_df = results_df.drop(columns=self.empty_runs_to_investigate)
+        #run_empty_results = results_df.sum(axis = 0)
+        #self.empty_runs_to_investigate = list(run_empty_results.index[run_empty_results == 0])
+        #results_df = results_df.drop(columns=self.empty_runs_to_investigate)
 
         if not jsonized_output :
             renaming_dictionary = {}
@@ -134,10 +133,12 @@ class ParallelRunResultAnalyzer():
             local_df = self.analyzeLocalAllRunSignalsResults(table_number,jsonized_output)
             if local_df is not None:
                 if results_df is None:
-                    results_df = local_df.copy()
+                    if local_df.shape[0]>0 and local_df.shape[1]>0:
+                        results_df = local_df.copy()
                 else:
-                    print('merging table ' + str(local_df.shape))
-                    results_df = pd.merge(results_df, local_df, how='left', on=['Date'])
+                    if local_df.shape[0]>0 and local_df.shape[1]>0:
+                        print('merging table ' + str(local_df.shape))
+                        results_df = pd.merge(results_df, local_df, how='left', on=['Date'])
             else :
                 break
         return results_df
@@ -147,10 +148,10 @@ class ParallelRunResultAnalyzer():
         for table_number in range(self.max_table_number):
             local_df = self.analyzeLocalAllRunPerfResults(table_number,jsonized_output)
             if local_df is not None:
-                if results_df is None:
+                if results_df is None and local_df.shape[1]>0:
                     results_df = local_df.copy()
                 else:
-                    if local_df.shape[0]>0:
+                    if local_df.shape[0]>0 and local_df.shape[1]>0:
                         print('merging table ' + str(local_df.shape))
                         results_df = pd.merge(results_df, local_df, how='left', on=['Date'])
             else :
