@@ -16,10 +16,12 @@ import json
 
 
 class AbstractRunner(ABC):
-    def __init__(self, starting_date = None, running_date = None, drop_token=None, dropbox_backup = True, freqly_pkl_file_name='freqly_candels.pkl', local_root_directory='../data/', user = 'napoleon',nb_items_per_year=252):
+    def __init__(self, starting_date = None, running_date = None, drop_token=None, dropbox_backup = True, underlying = None, freqly_pkl_file_name_sufffix='freqly_candels.pkl', local_root_directory='../data/', user = 'napoleon',nb_items_per_year=252):
         super().__init__()
-        self.freqly_pkl_file_name=freqly_pkl_file_name
+        self.freqly_pkl_file_name_sufffix=freqly_pkl_file_name_sufffix
+        self.underlying = underlying
         self.local_root_directory=local_root_directory
+        self.saving_return_path = self.local_root_directory+self.underlying+self.freqly_pkl_file_name_sufffix
         self.user=user
         self.dropbox_backup = dropbox_backup
         self.dbx = dropbox_file_saver.NaPoleonDropboxConnector(drop_token=drop_token,dropbox_backup=dropbox_backup)
@@ -45,7 +47,9 @@ class SimpleSignalRunner(AbstractRunner):
             print('not normalizing a not continuous signal')
             return
         print('Launching computation with parameters : '+saving_key)
-        freqly_df = pd.read_pickle(self.local_root_directory+self.freqly_pkl_file_name)
+        freqly_df = pd.read_pickle(self.saving_return_path)
+        print('number of duplicated dates')
+        print(freqly_df.index.duplicated().sum())
         freqly_df = freqly_df.sort_index()
         print('time range before filtering ')
         print(max(freqly_df.index))
@@ -70,14 +74,18 @@ class SimpleSignalRunner(AbstractRunner):
                 print('Trouble backtesting signal')
                 print(inst)
                 return
+
+
         freqly_df = signal_utility.reconstitute_signal_perf(data = freqly_df, transaction_cost = transaction_costs , normalization = normalization)
         sharpe_strat = metrics.sharpe(freqly_df['perf_return'].dropna(), period= self.nb_items_per_year, from_ret=True)
         sharpe_under = metrics.sharpe(freqly_df['close_return'].dropna(), period= self.nb_items_per_year, from_ret=True)
+        freqly_df = freqly_df.dropna()
         print('underlying sharpe')
         print(sharpe_under)
         print('strat sharpe')
         print(sharpe_strat)
         saver.saveAll(saving_key, freqly_df)
+        print('save done')
         return
 
 
