@@ -1131,6 +1131,39 @@ def optimize_filtering_wlt(decomp_components, threshold):
         output_approx = output_approx + 1*(returns[i]<threshold*returns[-1])*decomp_components[i]
     return output_approx
 
+def soft_thresholding_like(decomp_components):
+    soft_arr = np.zeros(decomp_components.shape)
+    for i in range(len(decomp_components)):
+        threshold = np.sqrt(2*np.log(len(decomp_components[i]))*np.var(decomp_components[i]))
+        soft_arr[i] = (decomp_components[i]-threshold)
+    return soft_arr
+
+def signe(a):
+    if a>=0:
+        return 1
+    else:
+        return -1
+
+def select_orthogonal_coef(wtmra, dec_level, coeff_index_factor):
+    components = wtmra.copy()
+    ortho_coeff = np.zeros(components.shape)
+    for j in range(len(components)):
+        current_array = np.zeros(components[j].shape)
+
+        if j == len(components) - 1:  # Case of the approximation
+            for k in range(coeff_index_factor):  # range(2):
+                a = len(wtmra[0]) - 2 ** (j) * (k)
+                if -1 * (len(wtmra[0]) + 1) <= a <= len(wtmra[0]):
+                    current_array[a - signe(a)] = 1
+
+        else:
+            for k in range(coeff_index_factor):  # range(2**(J-(j+1))+1):
+                a = len(wtmra[0]) - 2 ** (j + 1) * (k)
+                if -1 * (len(wtmra[0]) + 1) <= a <= len(wtmra[0]):
+                    current_array[a - signe(a)] = 1
+
+        ortho_coeff[j] = current_array * components[j]
+    return sum(ortho_coeff)
 
 def is_discrete(wavelet_to_check, discrete):
     prefix_size = len(wavelet_to_check)
@@ -1146,14 +1179,18 @@ def set_wavelet_filters(kind='discrete'):
             selected_filters.append(random.choice(pywt.wavelist(family=wavelet, kind=kind)))
     return selected_filters
 
-def fourier_wvt_decompo_lo(data=None, filter_name='haar', contravariant=1., dec_level=2, n_harm=5, fft_filter_type='low', threshold=0.7, **kwargs):
+def fourier_wvt_decompo_lo(data=None, filter_name='haar', contravariant=1., dec_level=2, n_harm=5, fft_filter_type='low', optimize_filtering = True, threshold=0.7, soft_filtering = True, **kwargs):
     n_predict = 1
     try:
         x = data['close'].values
         last_available_close = x[-1]
         wt = wavelet_features.modwt(x, filter_name, dec_level)
         decomp_components = wavelet_features.modwtmra(wt, filter_name)
-        approx = optimize_filtering_wlt(decomp_components, threshold)
+        if soft_filtering:
+            decomp_components = soft_thresholding_like(decomp_components)
+        approx = decomp_components[-1]
+        if optimize_filtering:
+            approx = optimize_filtering_wlt(decomp_components, threshold)
         lb_signal = fourier_extrapolation(approx, n_predict, n_harm, fft_filter_type)
         next_close = lb_signal[0]
         test = contravariant * np.sign(next_close - last_available_close)
@@ -1164,14 +1201,18 @@ def fourier_wvt_decompo_lo(data=None, filter_name='haar', contravariant=1., dec_
     except:
         return np.nan
 
-def fourier_wvt_decompo_ls(data=None, filter_name='haar', contravariant=1., dec_level=2, n_harm=5, fft_filter_type='low', threshold=0.7, **kwargs):
+def fourier_wvt_decompo_ls(data=None, filter_name='haar', contravariant=1., dec_level=2, n_harm=5, fft_filter_type='low', optimize_filtering = True, threshold=0.7, soft_filtering = True, **kwargs):
     n_predict = 1
     try:
         x = data['close'].values
         last_available_close = x[-1]
         wt = wavelet_features.modwt(x, filter_name, dec_level)
         decomp_components = wavelet_features.modwtmra(wt, filter_name)
-        approx = optimize_filtering_wlt(decomp_components, threshold)
+        if soft_filtering:
+            decomp_components = soft_thresholding_like(decomp_components)
+        approx = decomp_components[-1]
+        if optimize_filtering:
+            approx = optimize_filtering_wlt(decomp_components, threshold)
         lb_signal = fourier_extrapolation(approx, n_predict, n_harm, fft_filter_type)
         next_close = lb_signal[0]
         return contravariant * np.sign(next_close - last_available_close)
@@ -1179,6 +1220,38 @@ def fourier_wvt_decompo_ls(data=None, filter_name='haar', contravariant=1., dec_
         return np.nan
 
 
+def fourier_wvt_ortho_decompo_lo(data=None, filter_name='haar', dec_level=2, n_harm=5,
+                                 fft_filter_type='low', coeff_index_factor=2, **kwargs):
+    n_predict = 1
+    try:
+        x = data['return'].values
+        wt = wavelet_features.modwt(x, filter_name, dec_level)
+        decomp_components = wavelet_features.modwtmra(wt, filter_name)
+        approx = select_orthogonal_coef(decomp_components, dec_level, coeff_index_factor)
+        lb_signal = fourier_extrapolation(approx, n_predict, n_harm, fft_filter_type)
+        next_return = lb_signal[0]
+        test = np.sign(next_return)
+        if test > 0:
+            return 1
+        else:
+            return np.nan
+    except:
+        return np.nan
+
+def fourier_wvt_ortho_decompo_ls(data=None, filter_name='haar', dec_level=2, n_harm=5, fft_filter_type='low', coeff_index_factor=2, **kwargs):
+    n_predict = 1
+    try:
+        x = data['return'].values
+        wt = wavelet_features.modwt(x, filter_name, dec_level)
+        decomp_components = wavelet_features.modwtmra(wt, filter_name)
+        approx = select_orthogonal_coef(decomp_components, dec_level, coeff_index_factor)
+        lb_signal = fourier_extrapolation(approx, n_predict, n_harm, fft_filter_type)
+        next_return = lb_signal[0]
+        return np.sign(next_return)
+    except:
+        return np.nan
+
+
 def kalman_filtering_ls(data=None, observation_covariance=0.01, contravariant=1, n_harm=5, fft_filter_type='low',
                               n_dim_obs=1, n_dim_state=2,**kwargs):
     n_predict = 1
@@ -1236,4 +1309,4 @@ def kalman_filtering_lo(data=None, observation_covariance=0.01, contravariant=1,
         else:
             return np.nan
     except:
-        return np.nan
+        return np.nan
\ No newline at end of file
